@@ -148,23 +148,7 @@ gsf_input_stdio_new (char const *filename, GError **err)
 	input->keep_open = FALSE;
 	gsf_input_set_size (GSF_INPUT (input), size);
 	gsf_input_set_name_from_filename (GSF_INPUT (input), filename);
-	if (st.st_mtime != (time_t)-1) {
-		GDateTime *modtime;
-		GTimeVal tv;
-
-		tv.tv_sec = st.st_mtime;
-#if defined (HAVE_STRUCT_STAT_ST_MTIMENSEC)
-		tv.tv_usec = st.st_mtimensec / 1000;
-#elif defined (HAVE_STRUCT_STAT_ST_MTIM_TV_NSEC)
-		tv.tv_usec =  st.st_mtim.tv_nsec / 1000;
-#else
-		tv.tv_usec = 0;
-#endif
-
-		modtime = g_date_time_new_from_timeval_utc (&tv);
-		gsf_input_set_modtime (GSF_INPUT (input), modtime);
-		g_date_time_unref (modtime);
-	}
+	gsf_input_set_modtime_from_stat (GSF_INPUT (input), &st);
 
 	return GSF_INPUT (input);
 }
